@@ -15,7 +15,8 @@ __docformat__ = "numpydoc"
 
 
 # %% Function definitions
-def plot_sum_fig(polynomials_sum: np.ndarray, r: np.ndarray, theta: np.ndarray, title: str = ""):
+def plot_sum_fig(polynomials_sum: np.ndarray, r: np.ndarray, theta: np.ndarray, title: str = "",
+                 color_map: str = "coolwarm"):
     """
     Plot specified profile of Zernike polynomials sum (or single polynomial) on a mesh of polar coordinates (r, theta).
 
@@ -29,6 +30,8 @@ def plot_sum_fig(polynomials_sum: np.ndarray, r: np.ndarray, theta: np.ndarray,
         Vector with theta angles as polar coordinates.
     title : str, optional
         Title for representing on the Figure, useful for the single Zernike polynomial plotting. The default is "".
+    color_map : str, optional
+        Color map of the polar plot, recommended values: coolwarm, jet, turbo, rainbow. The default is "coolwarm".
 
     Returns
     -------
@@ -38,7 +41,7 @@ def plot_sum_fig(polynomials_sum: np.ndarray, r: np.ndarray, theta: np.ndarray,
     plt.ioff()  # blocks the call of plt.show() for running this script in some IDEs (e.g., PyCharm)
     plt.figure(figsize=(4, 4))  # since the figure has the circular shape, better draw it on equal box
     axes = plt.axes(projection='polar'); axes.grid(False)
-    plt.pcolormesh(theta, r, polynomials_sum, cmap=plt.cm.coolwarm, shading='nearest')  # fast draw of 2D polar surface
+    plt.pcolormesh(theta, r, polynomials_sum, cmap=color_map, shading='nearest')  # fast draw of 2D polar surface
     if isinstance(title, str) and len(title) > 0:
         plt.title(title)
     plt.subplots_adjust(left=0.0, bottom=0.0, right=1.0, top=1.0)
@@ -47,7 +50,7 @@ def plot_sum_fig(polynomials_sum: np.ndarray, r: np.ndarray, theta: np.ndarray,
 
 
 def subplot_sum_on_fig(figure: plt.Figure, polynomials_sum: np.ndarray, r: np.ndarray, theta: np.ndarray,
-                       show_range_colorbar: bool = False) -> plt.Figure:
+                       show_range_colorbar: bool = False, color_map: str = "coolwarm") -> plt.Figure:
     """
     Plot on the provided figure the sum of Zernike polynomials calculated based on a mesh of polar coordinates r, theta.
 
@@ -63,6 +66,8 @@ def subplot_sum_on_fig(figure: plt.Figure, polynomials_sum: np.ndarray, r: np.nd
         Vector with theta angles as polar coordinates.
     show_range_colorbar : bool, optional
         Flag for showing range of provided values as the colorbar on the figure. The default is False.
+    color_map : str, optional
+        Color map of the polar plot, recommended values: coolwarm, jet, turbo, rainbow. The default is "coolwarm".
 
     Returns
     -------
@@ -74,7 +79,7 @@ def subplot_sum_on_fig(figure: plt.Figure, polynomials_sum: np.ndarray, r: np.nd
     axes = figure.add_subplot(projection='polar')  # axes - the handle for drawing functions
     axes.grid(False)  # demanded by pcolormesh function, if not called - deprecation warning
     # plot the colour map by using the Zernikes values according to Theta, R coordinates
-    im = axes.pcolormesh(theta, r, polynomials_sum, cmap=plt.cm.coolwarm, shading='nearest')
+    im = axes.pcolormesh(theta, r, polynomials_sum, cmap=color_map, shading='nearest')
     axes.axis('off')  # off polar coordinate axes
     # below: shows the colour bar with shown on image amplitudes
     if show_range_colorbar:
